package com.girafi.waddles;

import com.girafi.waddles.entity.EntityAdeliePenguin;
import com.girafi.waddles.proxy.CommonProxy;
import com.girafi.waddles.utils.ConfigurationHandler;
import com.girafi.waddles.utils.Reference;
import com.google.common.collect.Lists;
import com.google.common.collect.Sets;
import net.minecraft.entity.EntityAgeable;
import net.minecraft.entity.EnumCreatureType;
import net.minecraft.util.ResourceLocation;
import net.minecraft.world.biome.Biome;
import net.minecraft.world.storage.loot.LootTableList;
import net.minecraftforge.common.BiomeDictionary;
import net.minecraftforge.common.MinecraftForge;
import net.minecraftforge.common.config.Configuration;
import net.minecraftforge.fml.common.Mod;
import net.minecraftforge.fml.common.SidedProxy;
import net.minecraftforge.fml.common.event.FMLInitializationEvent;
import net.minecraftforge.fml.common.event.FMLPreInitializationEvent;
import net.minecraftforge.fml.common.registry.EntityRegistry;

import java.io.File;
import java.util.List;
import java.util.Set;

import static net.minecraftforge.common.BiomeDictionary.Type.*;

@Mod(modid = Reference.MOD_ID, name = Reference.MOD_NAME, version = Reference.MOD_VERSION, dependencies = Reference.DEPENDENCIES, guiFactory = Reference.GUI_FACTORY_CLASS)
public class Waddles {
    @Mod.Instance(Reference.MOD_ID)
    public static Waddles instance;

    @SidedProxy(clientSide = Reference.CLIENT_PROXY_CLASS, serverSide = Reference.COMMON_PROXY_ClASS)
    public static CommonProxy proxy;

    public static final ResourceLocation LOOT_ENTITIES_PENGUIN_FISH = LootTableList.func_186375_a(new ResourceLocation(Reference.MOD_ID, "entities/penguin"));

    @Mod.EventHandler
    public void preInit(FMLPreInitializationEvent event) {
        ConfigurationHandler.init(new File(event.getModConfigurationDirectory(), "Waddles.cfg"));
        MinecraftForge.EVENT_BUS.register(new ConfigurationHandler());
        proxy.registerRenders();
    }

    @Mod.EventHandler
    public void init(FMLInitializationEvent event) {
        EntityRegistry.registerModEntity(EntityAdeliePenguin.class, "penguin", 0, Waddles.instance, 64, 1, true, 0x000000, 0xFFFFFF);

        List<Biome> spawnable_biomes = Lists.newArrayList();
        for (Biome biome : Biome.field_185377_q) {
            Set<BiomeDictionary.Type> types = Sets.newHashSet(BiomeDictionary.getTypesForBiome(biome));
            if (types.contains(SNOWY) && !types.contains(FOREST) && !types.contains(NETHER) && !biome.func_76747_a(EnumCreatureType.CREATURE).isEmpty()) {
                System.out.println("Spawn Penguin");
                spawnable_biomes.add(biome);
            }
        }
        addPenguinSpawn(EntityAdeliePenguin.class, 2, 1, 4, spawnable_biomes.toArray(new Biome[spawnable_biomes.size()]));
    }

    private void addPenguinSpawn(Class<? extends EntityAgeable> penguinClass, int defaultWeight, int defaultMin, int defaultMax, Biome... biomes) {
        String subCategoryNames = ConfigurationHandler.CATEGORY_PENGUIN_SPAWNS + Configuration.CATEGORY_SPLITTER + "adelie_penguin";
        int weight = ConfigurationHandler.config.get(subCategoryNames, "Weight", defaultWeight).getInt();
        int min = ConfigurationHandler.config.get(subCategoryNames, "Min", defaultMin).getInt();
        int max = ConfigurationHandler.config.get(subCategoryNames, "Max", defaultMax).getInt();

        ConfigurationHandler.config.save();

        if (weight != 0) {
            EntityRegistry.addSpawn(penguinClass, weight, min, max, EnumCreatureType.CREATURE, biomes);
        }
    }
}
